[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Open:FactSet Partners - Documents client library for Python

[![API Version](https://img.shields.io/badge/api-v2.0.0-blue)](https://developer.factset.com/api-catalog/openfactset-partners-documents)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.OpenFactSetPartnersDocuments)](https://pypi.org/project/fds.sdk.OpenFactSetPartnersDocuments/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

This service provides the capability to search and download unstructured content provided by <a href=\"https://open.factset.com/catalog/en-us\">Open:FactSet Partners</a>.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- SDK version: 3.0.10
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.OpenFactSetPartnersDocuments==3.0.10
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.OpenFactSetPartnersDocuments==3.0.10
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.OpenFactSetPartnersDocuments
from fds.sdk.OpenFactSetPartnersDocuments.api import link_up_api
from fds.sdk.OpenFactSetPartnersDocuments.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.OpenFactSetPartnersDocuments.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.OpenFactSetPartnersDocuments.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.OpenFactSetPartnersDocuments.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = link_up_api.LinkUpApi(api_client)
    sort = "-startDate" # str | Enables to get the data in ascending or descending order based on startTime. Results are in reverse chronological order if this parameter is not used. (optional) if omitted the server will use the default value of "-startDate"
    pagination_limit = 20 # int | Specifies the maximum number of results to return per result. (optional) if omitted the server will use the default value of 20
    pagination_offset = 0 # int | Specifies the starting point for pagination. This parameter is used to identify the beginning of next set of results. Using this parameter can fetch maximum of first 10000 records. (optional) if omitted the server will use the default value of 0
    start_date = dateutil_parser('2020-01-01').date() # date | The earliest date of the LinkUp file the API should fetching for based on fileTimestamp. (optional)
    end_date = dateutil_parser('2021-08-01').date() # date | The latest date of the LinkUp file the API should fetching for based on fileTimestamp. (optional)
    type = "delta" # str | Used to provide the full job descriptions when value \"full\" is used for this parameter. (optional) if omitted the server will use the default value of "delta"

    try:
        # Returns the  daily files from Open:FactSet Partner - LinkUp. The LinkUp API provides access to job listings dataset that is sourced directly from employer webistes globally delivered daily.
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_link_up_job_listings(sort=sort, pagination_limit=pagination_limit, pagination_offset=pagination_offset, start_date=start_date, end_date=end_date, type=type)

        pprint(api_response)
    except fds.sdk.OpenFactSetPartnersDocuments.ApiException as e:
        print("Exception when calling LinkUpApi->get_link_up_job_listings: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Returns the  daily files from Open:FactSet Partner - LinkUp. The LinkUp API provides access to job listings dataset that is sourced directly from employer webistes globally delivered daily.
    #     api_response, http_status_code, response_headers = api_instance.get_link_up_job_listings_with_http_info(sort=sort, pagination_limit=pagination_limit, pagination_offset=pagination_offset, start_date=start_date, end_date=end_date, type=type)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.OpenFactSetPartnersDocuments.ApiException as e:
    #     print("Exception when calling LinkUpApi->get_link_up_job_listings: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Returns the  daily files from Open:FactSet Partner - LinkUp. The LinkUp API provides access to job listings dataset that is sourced directly from employer webistes globally delivered daily.
    #     async_result = api_instance.get_link_up_job_listings_async(sort=sort, pagination_limit=pagination_limit, pagination_offset=pagination_offset, start_date=start_date, end_date=end_date, type=type)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.OpenFactSetPartnersDocuments.ApiException as e:
    #     print("Exception when calling LinkUpApi->get_link_up_job_listings: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Returns the  daily files from Open:FactSet Partner - LinkUp. The LinkUp API provides access to job listings dataset that is sourced directly from employer webistes globally delivered daily.
    #     async_result = api_instance.get_link_up_job_listings_with_http_info_async(sort=sort, pagination_limit=pagination_limit, pagination_offset=pagination_offset, start_date=start_date, end_date=end_date, type=type)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.OpenFactSetPartnersDocuments.ApiException as e:
    #     print("Exception when calling LinkUpApi->get_link_up_job_listings: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.OpenFactSetPartnersDocuments

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.OpenFactSetPartnersDocuments.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.OpenFactSetPartnersDocuments

configuration = fds.sdk.OpenFactSetPartnersDocuments.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.OpenFactSetPartnersDocuments

configuration = fds.sdk.OpenFactSetPartnersDocuments.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.OpenFactSetPartnersDocuments

configuration = fds.sdk.OpenFactSetPartnersDocuments.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/bulk-documents/ofm/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*LinkUpApi* | [**get_link_up_job_listings**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/LinkUpApi.md#get_link_up_job_listings) | **GET** /linkup/job-listings | Returns the  daily files from Open:FactSet Partner - LinkUp. The LinkUp API provides access to job listings dataset that is sourced directly from employer webistes globally delivered daily.
*LuxembourgApi* | [**get_luxembourg_greenbonds_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/LuxembourgApi.md#get_luxembourg_greenbonds_daily) | **GET** /luxembourg/green-bonds/daily | Returns daily files from Open:FactSet Partner - Luxembourg
*OrbitApi* | [**get_chinese_transcripts_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OrbitApi.md#get_chinese_transcripts_daily) | **GET** /orbit/transcripts/daily | Returns the daily files from Open:FactSet Partner - Orbit.
*OrbitApi* | [**get_chinese_transcripts_history**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OrbitApi.md#get_chinese_transcripts_history) | **GET** /orbit/transcripts/history | Returns the history files from Open:FactSet Partner - Orbit
*OzmosiApi* | [**get_ozmosi_biomarkers_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_biomarkers_daily) | **GET** /ozmosi/biomarkers/daily | Returns the daily files of Biomarkers Details from Open:FactSet Partner - Ozmosi.
*OzmosiApi* | [**get_ozmosi_clinical_trials_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_clinical_trials_daily) | **GET** /ozmosi/clinical-trials/daily | Returns the daily files of Clinical Trial Details from Open:FactSet Partner - Ozmosi.
*OzmosiApi* | [**get_ozmosi_clinical_trials_history**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_clinical_trials_history) | **GET** /ozmosi/clinical-trials/history | Returns the history files from Open:FactSet Partner - Ozmosi
*OzmosiApi* | [**get_ozmosi_collaborators_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_collaborators_daily) | **GET** /ozmosi/collaborators/daily | Returns the daily files of Collaborators Details from Open:FactSet Partner - Ozmosi.
*OzmosiApi* | [**get_ozmosi_diseases_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_diseases_daily) | **GET** /ozmosi/diseases/daily | Returns the daily files of Diseases Details from Open:FactSet Partner- Ozmosi.
*OzmosiApi* | [**get_ozmosi_endpoints_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_endpoints_daily) | **GET** /ozmosi/beam-endpoints/daily | Returns the daily files of Beam Endpoints Details from Open:FactSet Partner - Ozmosi.
*OzmosiApi* | [**get_ozmosi_intervention_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_intervention_daily) | **GET** /ozmosi/intervention/daily | Returns the daily files of Intervention details from Open:FactSet Partner - Ozmosi.
*OzmosiApi* | [**get_ozmosi_orangepurple_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_orangepurple_daily) | **GET** /ozmosi/orangepurple/daily | Returns the daily files of OrangePurple Details from Open:FactSet Partner - Ozmosi.
*OzmosiApi* | [**get_ozmosi_primaryoutcome_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_primaryoutcome_daily) | **GET** /ozmosi/primaryoutcome/daily | Returns the daily files of PrimaryOutcome Details from Open:FactSet Partner - Ozmosi.
*OzmosiApi* | [**get_ozmosi_sponsors_daily**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OzmosiApi.md#get_ozmosi_sponsors_daily) | **GET** /ozmosi/sponsors/daily | Returns the daily files of Sponsors Details from Open:FactSet Partner - Ozmosi.
*ScriptsAsiaApi* | [**get_scripts_asia_files**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/ScriptsAsiaApi.md#get_scripts_asia_files) | **GET** /scripts-asia/transcripts | Returns the daily files from Open:FactSet Partner - Scripts Asia.


## Documentation For Models

 - [AuthStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/AuthStatus.md)
 - [BeamEndpointsFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/BeamEndpointsFiles.md)
 - [BeamEndpointsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/BeamEndpointsResponse.md)
 - [BiomarkersFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/BiomarkersFiles.md)
 - [BiomarkersResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/BiomarkersResponse.md)
 - [Bonds](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/Bonds.md)
 - [CollaboratorsFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/CollaboratorsFiles.md)
 - [CollaboratorsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/CollaboratorsResponse.md)
 - [DataFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/DataFiles.md)
 - [DataResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/DataResponse.md)
 - [DiseasesFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/DiseasesFiles.md)
 - [DiseasesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/DiseasesResponse.md)
 - [ErrorExample](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/ErrorExample.md)
 - [FullHistoryFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/FullHistoryFiles.md)
 - [FullHistoryResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/FullHistoryResponse.md)
 - [InterventionFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/InterventionFiles.md)
 - [InterventionResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/InterventionResponse.md)
 - [LinkUpResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/LinkUpResponse.md)
 - [LinkupFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/LinkupFiles.md)
 - [LuxResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/LuxResponse.md)
 - [Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/Meta.md)
 - [OrangePurpleFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OrangePurpleFiles.md)
 - [OrangePurpleResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OrangePurpleResponse.md)
 - [OrbitFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OrbitFiles.md)
 - [OrbitHistoryFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OrbitHistoryFiles.md)
 - [OrbitResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OrbitResponse.md)
 - [OrbithistoryResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/OrbithistoryResponse.md)
 - [Pagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/Pagination.md)
 - [PrimaryOutcomeFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/PrimaryOutcomeFiles.md)
 - [PrimaryOutcomeResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/PrimaryOutcomeResponse.md)
 - [ScriptsAsiaResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/ScriptsAsiaResponse.md)
 - [SponsorsFiles](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/SponsorsFiles.md)
 - [SponsorsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/SponsorsResponse.md)
 - [Transcripts](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/OpenFactSetPartnersDocuments/v2/docs/Transcripts.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.OpenFactSetPartnersDocuments.apis and fds.sdk.OpenFactSetPartnersDocuments.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.OpenFactSetPartnersDocuments.api.default_api import DefaultApi`
- `from fds.sdk.OpenFactSetPartnersDocuments.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.OpenFactSetPartnersDocuments
from fds.sdk.OpenFactSetPartnersDocuments.apis import *
from fds.sdk.OpenFactSetPartnersDocuments.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

